==> flutter_windows_1.17.0-stable.zip: flutter/.pub-cache/hosted/pub.dartlang.org/_fe_analyzer_shared-1.0.3/test/constants/data/type_literals.dart <==
// Copyright (c) 2019, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:async';

typedef Typedef();
typedef GenericTypedef<T> = void Function(T);
typedef GenericFunctionTypedef = void Function<T>(T);
typedef TypedefWithFutureOr = void Function<T>(FutureOr<T>);

const typedef = /*cfe.TypeLiteral(dynamic Function())*/ Typedef;
const genericTypedef =
    /*cfe.TypeLiteral(void Function(dynamic))*/ GenericTypedef;
const genericFunctionTypedef =
    /*cfe.TypeLiteral(void Function<T>(T))*/ GenericFunctionTypedef;
const typedefWithFutureOr =
    /*cfe.TypeLiteral(void Function<T>(FutureOr<T>))*/ TypedefWithFutureOr;
const futureOr = /*cfe.TypeLiteral(FutureOr<dynamic>)*/ FutureOr;
const null_ = /*cfe.TypeLiteral(Null)*/ Null;

main() {
  print(
      /*cfe|analyzer.TypeLiteral(dynamic Function())*/
      /*dart2js.TypeLiteral(Typedef)*/
      typedef);

  print(
      /*cfe|analyzer.TypeLiteral(void Function(dynamic))*/
      /*dart2js.TypeLiteral(GenericTypedef<dynamic>)*/
      genericTypedef);

  print(
      /*cfe|analyzer.TypeLiteral(void Function<T>(T))*/
      /*dart2js.TypeLiteral(GenericFunctionTypedef)*/
      genericFunctionTypedef);

  print(
      /*cfe|analyzer.TypeLiteral(void Function<T>(FutureOr<T>))*/
      /*dart2js.TypeLiteral(TypedefWithFutureOr)*/
      typedefWithFutureOr);

  print(
      /*TypeLiteral(FutureOr<dynamic>)*/
      futureOr);

  print(
      /*TypeLiteral(Null)*/
      null_);
}

==> flutter_windows_1.20.2-stable.zip: flutter/.pub-cache/hosted/pub.dartlang.org/_fe_analyzer_shared-5.0.0/test/constants/data/type_literals.dart <==
// Copyright (c) 2019, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:async';

typedef Typedef();
typedef GenericTypedef<T> = void Function(T);
typedef GenericFunctionTypedef = void Function<T>(T);
typedef TypedefWithFutureOr = void Function<T>(FutureOr<T>);

const typedef = /*cfe.TypeLiteral(dynamic Function())*/ Typedef;
const genericTypedef =
    /*cfe.TypeLiteral(void Function(dynamic))*/ GenericTypedef;
const genericFunctionTypedef =
    /*cfe.TypeLiteral(void Function<T>(T))*/ GenericFunctionTypedef;
const typedefWithFutureOr =
    /*cfe.TypeLiteral(void Function<T>(FutureOr<T>))*/ TypedefWithFutureOr;
const futureOr = /*cfe.TypeLiteral(FutureOr<dynamic>)*/ FutureOr;
const null_ = /*cfe.TypeLiteral(Null)*/ Null;

main() {
  print(
      /*cfe|analyzer.TypeLiteral(dynamic Function())*/
      /*dart2js.TypeLiteral(()->dynamic)*/
      typedef);

  print(
      /*cfe|analyzer.TypeLiteral(void Function(dynamic))*/
      /*dart2js.TypeLiteral((dynamic)->void)*/
      genericTypedef);

  print(
      /*cfe|analyzer.TypeLiteral(void Function<T>(T))*/
      /*dart2js.TypeLiteral((0)->void)*/
      genericFunctionTypedef);

  print(
      /*cfe|analyzer.TypeLiteral(void Function<T>(FutureOr<T>))*/
      /*dart2js.TypeLiteral((FutureOr<0>)->void)*/
      typedefWithFutureOr);

  print(
      /*cfe|analyzer.TypeLiteral(FutureOr<dynamic>)*/
      /*dart2js.TypeLiteral(dynamic)*/
      futureOr);

  print(
      /*TypeLiteral(Null)*/
      null_);
}
